/* GCC */
#include <fstream>
#include <vector>
#include <algorithm>

using namespace std;

struct Corner
{
    Corner(int _x, int _from, int _to, bool _left)
        : x(_x), from(_from), to(_to), left(_left)
    {};
    int x;
    int from;
    int to;
    bool left;
};

int country[200], city[200], n, m, d, ans_d, ans(0), cur_ans(0), mt[200];
vector<int> gr[200];
bool conn[200][200] = {}, used[200] = {}, used_kuhn[200] = {};

bool operator<(const Corner& c1, const Corner& c2)
{
    if(c1.x < c2.x) return true;
    if(c1.x > c2.x) return false;
    return c1.left > c2.left;
}

bool try_kuhn(int v)
{
    if(used_kuhn[v])
        return false;
    used_kuhn[v] = true;
    for(int i = 0; i < gr[v].size(); ++i)
    {
        const int to = gr[v][i];
        if(!conn[v][to])
        {
            swap(gr[v][i], gr[v][gr[v].size() - 1]);
            gr[v].pop_back();
            --i;
            continue;
        }
        if(mt[to] == -1 || try_kuhn(mt[to]))
        {
            mt[to] = v;
            return true;
        }
    }
    return false;
}

bool update(void)
{
    bool pre = true;
    for(int i = 0; i < n; ++i)
        if(!used[i])
        {
            if(pre)
                fill(used_kuhn, used_kuhn + n, false);
            cur_ans += (pre = used[i] = try_kuhn(i));
        }
    if(cur_ans > ans)
    {
        ans = cur_ans;
        return true;
    }
    return false;
}

int main(void)
{
	ifstream in("chess.in");
	in >> n >> m >> d;
	for(int i = 0; i < n; ++i)
        in >> country[i];
    for(int i = 0; i < m; ++i)
    {
        mt[i] = -1;
        in >> city[i];
    }
    in.close();
    vector<Corner> corners;
    for(int i = 0; i < n; ++i)
        for(int j = 0; j < m; ++j)
        {
            corners.push_back(Corner(city[j] - country[i] - d, i, j, true));
            corners.push_back(Corner(city[j] - country[i] + d, i, j, false));
        }
    sort(corners.begin(), corners.end());
    bool left_block = false;
    for(int i = 0; i < corners.size(); ++i)
    {
        const Corner& cur = corners[i];
        if(cur.left)
        {
            left_block = true;
            conn[cur.from][cur.to] = true;
            gr[cur.from].push_back(cur.to);
        }
        else
        {
            if(left_block)
            {
                left_block = false;
                if(update())
                    ans_d = corners[i].x; // [i - 1] ?
            }
            conn[cur.from][cur.to] = false;
            if(mt[cur.to] == cur.from)
                --cur_ans, mt[cur.to] = -1, used[cur.from] = false;
        }
    }
    for(int i = 0; corners[i].x < ans_d || (corners[i].x == ans_d && corners[i].left); ++i)
        if(corners[i].left)
        {
            conn[corners[i].from][corners[i].to] = true;
            gr[corners[i].from].push_back(corners[i].to);
        }
        else
            conn[corners[i].from][corners[i].to] = false;
    update();
	ofstream out("chess.out");
	out << ans << ' ' << ans_d << '\n';
	for(int i = 0; i < m; ++i)
        if(mt[i] != -1)
            out << mt[i] + 1 << ' ' << i + 1 << '\n';
	out.close();
	return 0;
}
